@@ -18,9 +18,9 @@ from dbnd._core.log.buffered_log_manager import BufferedLogManager
 from dbnd._core.tracking.airflow_dag_inplace_tracking import calc_task_key_from_af_ti
 from dbnd._core.tracking.script_tracking_manager import is_dbnd_tracking_active
 from dbnd._core.utils.basics import environ_utils
-from dbnd._core.utils.uid_utils import get_task_run_attempt_uid_from_af_ti
 from dbnd_airflow.tracking.execute_tracking import is_dag_eligable_for_tracking
 from dbnd_airflow.tracking.fakes import FakeTaskRun
+from dbnd_airflow.utils import get_task_run_attempt_uid_from_af_ti
 
 
 AIRFLOW_FILE_TASK_HANDLER = FileTaskHandler.__name__
@@ -125,7 +125,6 @@ class DbndAirflowHandler(logging.Handler):
                     task_run_attempt_uid=self.task_run_attempt_uid
                 )
                 in_memory_log_body = self.in_memory_log_manager.get_log_body()
-
                 self.dbnd_context.tracking_store.save_task_run_log(
                     task_run=fake_task_run, log_body=in_memory_log_body
                 )
@@ -182,14 +181,14 @@ def set_dbnd_handler():
     airflow_logger = logging.getLogger(AIRFLOW_TASK_LOGGER)
     dbnd_handler = DbndAirflowHandler(logger=airflow_logger)
 
-    base_file_handler = first_true(
+    inheriting_handler = first_true(
         airflow_logger.handlers,
         pred=lambda handler: handler.__class__.__name__ == AIRFLOW_FILE_TASK_HANDLER,
-        default=None,
+        default=airflow_logger.handlers[0] if airflow_logger.handlers else None,
     )
-    if base_file_handler:
-        handler_formatter = base_file_handler.formatter
+    if inheriting_handler:
+        handler_formatter = inheriting_handler.formatter
         dbnd_handler.setFormatter(handler_formatter)
-        for handler_filter in base_file_handler.filters:
+        for handler_filter in inheriting_handler.filters:
             dbnd_handler.addFilter(handler_filter)
     airflow_logger.addHandler(dbnd_handler)
